==> elgg-1.11.0.zip: elgg-1.11.0/mod/file/languages/pl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Pliki",
	'file:user' => "Pliki użytkownika %s",
	'file:friends' => "Pliki znajomych",
	'file:all' => "Wszystkie pliki",
	'file:edit' => "Edytuj plik",
	'file:more' => "Więcej plików",
	'file:list' => "widok listy",
	'file:group' => "Pliki w grupie",
	'file:gallery' => "Widok galerii",
	'file:gallery_list' => "Widok galerii lub listy",
	'file:num_files' => "Liczba plików do wyświetlenia",
	'file:user:gallery'=>'Wyświetl galerię użytkownika %s',
	'file:upload' => "Wgraj plik",
	'file:replace' => 'Zastąp zawartość pliku (pozostaw puste aby nie zmieniać pliku)',
	'file:list:title' => "%s %s %s",
	'file:title:friends' => "Znajomi",

	'file:add' => 'Wgraj plik',

	'file:file' => "Plik",

	'file:list:list' => 'Przełącz do widoku listy',
	'file:list:gallery' => 'Przełącz do widoku galerii',

	'file:types' => "Typy dodawanych plików",

	'file:type:' => 'Pliki',
	'file:type:all' => "Wszystkie pliki",
	'file:type:video' => "Wideo",
	'file:type:document' => "Dokumenty",
	'file:type:audio' => "Muzyka",
	'file:type:image' => "Zdjęcia",
	'file:type:general' => "Ogólne",

	'file:user:type:video' => "Wideo użytkownika %s",
	'file:user:type:document' => "Dokumenty użytkownika %s",
	'file:user:type:audio' => "Muzyka użytkownika %s",
	'file:user:type:image' => "Zdjęcia użytkownika %s",
	'file:user:type:general' => "Ogólne pliki użytkownika %s",

	'file:friends:type:video' => "Wideo twoich znajomych",
	'file:friends:type:document' => "Dokumenty twoich znajomych",
	'file:friends:type:audio' => "Muzyka twoich znajomych",
	'file:friends:type:image' => "Zdjęcia twoich znajomych",
	'file:friends:type:general' => "Ogólne pliki twoich znajomych",

	'file:widget' => "Gadżet plików",
	'file:widget:description' => "Zaprezentuj swoje ostatnie pliki",

	'groups:enablefiles' => 'Włącz pliki grupy',

	'file:delete:confirm' => "Czy na pewno chcesz usunąć ten plik?",

	'file:upload_limit' => 'Maksymalny dozwolony rozmar pliku to %s',

	'file:tagcloud' => "Chmura tagów",

	'file:display:number' => "Liczba plików do wyświetlenia",

	'river:create:object:file' => '%s wgrał nowy plik %s',
	'river:comment:object:file' => '%s skomentował plik %s',

	'item:object:file' => 'Pliki',

	'file:notify:summary' => 'Nowy plik o nazwie %s',
	'file:notify:subject' => 'Nowy plik: %s',
	'file:notify:body' =>
'%s zamieścił nowy plik: %s

%s

Zobacz i skomentuj nowy plik:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Twój plik został pomyślnie zapisany.",
	'file:deleted' => "Plik został usunięty.",

	/**
	 * Error messages
	 */

	'file:none' => "Brak plików.",
	'file:uploadfailed' => "Przykro nam, nie można było zapisać pliku.",
	'file:downloadfailed' => "Przykro nam, ten plik nie jest dostępny w tej chwili.",
	'file:deletefailed' => "Plik nie może być usunięty w tej chwili.",
	'file:noaccess' => "Nie masz uprawnień do modyfikacji tego pliku",
	'file:nofile' => "Musisz wskazać plik",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/pl.php <==
<?php
return array(

	'item:object:file' => 'Pliki',
	'collection:object:file' => 'Files',
	'collection:object:file:all' => "All site files",
	'collection:object:file:owner' => "%s's files",
	'collection:object:file:friends' => "Friends' files",
	'collection:object:file:group' => "Group files",
	'add:object:file' => "Upload a file",
	'edit:object:file' => "Edit file",

	'file:more' => "Więcej plików",
	'file:list' => "widok listy",

	'file:num_files' => "Liczba plików do wyświetlenia",
	'file:replace' => 'Zastąp zawartość pliku (pozostaw puste aby nie zmieniać pliku)',
	'file:list:title' => "%s %s %s",
	'file:title:friends' => "Znajomi",

	'file:file' => "Plik",

	'file:list:list' => 'Przełącz do widoku listy',
	'file:list:gallery' => 'Przełącz do widoku galerii',

	'file:types' => "Typy dodawanych plików",

	'file:type:' => 'Pliki',
	'file:type:all' => "Wszystkie pliki",
	'file:type:video' => "Wideo",
	'file:type:document' => "Dokumenty",
	'file:type:audio' => "Muzyka",
	'file:type:image' => "Zdjęcia",
	'file:type:general' => "Ogólne",

	'file:user:type:video' => "Wideo użytkownika %s",
	'file:user:type:document' => "Dokumenty użytkownika %s",
	'file:user:type:audio' => "Muzyka użytkownika %s",
	'file:user:type:image' => "Zdjęcia użytkownika %s",
	'file:user:type:general' => "Ogólne pliki użytkownika %s",

	'file:friends:type:video' => "Wideo twoich znajomych",
	'file:friends:type:document' => "Dokumenty twoich znajomych",
	'file:friends:type:audio' => "Muzyka twoich znajomych",
	'file:friends:type:image' => "Zdjęcia twoich znajomych",
	'file:friends:type:general' => "Ogólne pliki twoich znajomych",

	'widgets:filerepo:name' => "File widget",
	'widgets:filerepo:description' => "Showcase your latest files",

	'groups:tool:file' => 'Enable group files',

	'river:object:file:create' => '%s uploaded the file %s',
	'river:object:file:comment' => '%s commented on the file %s',

	'file:notify:summary' => 'Nowy plik o nazwie %s',
	'file:notify:subject' => 'Nowy plik: %s',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "Brak plików.",
	'file:uploadfailed' => "Przykro nam, nie można było zapisać pliku.",
	'file:noaccess' => "Nie masz uprawnień do modyfikacji tego pliku",
	'file:cannotload' => "There was an error uploading the file",
);
